@@ -10,7 +10,7 @@ from ip3country import CountryLookup
 
 class _ConfigEvaluation:
 
-    def __init__(self, fetch_from_server=False, boolean_value=False, json_value={}, rule_id="", secondary_exposures=[]):
+    def __init__(self, fetch_from_server=False, boolean_value=False, json_value={}, rule_id="", secondary_exposures=[], allocated_experiment=None):
         if fetch_from_server is None:
             fetch_from_server = False
         self.fetch_from_server = fetch_from_server
@@ -26,6 +26,7 @@ class _ConfigEvaluation:
         if secondary_exposures is None:
             secondary_exposures = []
         self.secondary_exposures = secondary_exposures
+        self.allocated_experiment = allocated_experiment
 
 
 class _Evaluator:
@@ -33,6 +34,7 @@ class _Evaluator:
         self._configs = dict()
         self._gates = dict()
         self._id_lists = dict()
+        self._layers = dict()
         self._country_lookup = CountryLookup()
 
         self._gate_overrides = dict()
@@ -51,8 +53,15 @@ class _Evaluator:
             if name is not None:
                 new_configs[name] = config
 
+        new_layers = dict()
+        for config in configs.get("layer_configs", []):
+            name = config.get("name")
+            if name is not None:
+                new_layers[name] = config
+
         self._gates = new_gates
         self._configs = new_configs
+        self._layers = new_layers
 
     def get_id_lists(self):
         return self._id_lists
@@ -105,19 +114,24 @@ class _Evaluator:
         if override is not None:
             return override
         eval_gate = self._gates.get(gate)
-        if eval_gate is None:
-            return _ConfigEvaluation()
-        return self.__evaluate(user, eval_gate)
+        return self.__eval_config(user, eval_gate)
 
     def get_config(self, user, config):
         override = self.__lookup_config_override(user, config)
         if override is not None:
             return override
         eval_config = self._configs.get(config)
-        if eval_config is None:
+        return self.__eval_config(user, eval_config)
+
+    def get_layer(self, user, layer):
+        eval_layer = self._layers.get(layer)
+        return self.__eval_config(user, eval_layer)
+
+    def __eval_config(self, user, config):
+        if config is None:
             return _ConfigEvaluation()
 
-        return self.__evaluate(user, eval_config)
+        return self.__evaluate(user, config)
 
     def __check_id_in_list(self, id, list_name):
         list = self._id_lists.get(list_name)
@@ -149,10 +163,15 @@ class _Evaluator:
                 exposures = exposures + result.secondary_exposures
             if result.boolean_value:
                 user_passes = self.__eval_pass_percentage(user, rule, config)
-                return_value = rule.get("returnValue", defaultValue)
-                config = return_value if user_passes else defaultValue
-                rule_id = rule.get("id", "")
-                return _ConfigEvaluation(False, user_passes, config, rule_id, exposures)
+                return _ConfigEvaluation(
+                    False,
+                    user_passes,
+                    result.json_value if user_passes else defaultValue,
+                    result.rule_id,
+                    exposures,
+                    result.allocated_experiment
+                )
+
         return _ConfigEvaluation(False, False, defaultValue, "default", exposures)
 
     def __evaluate_rule(self, user, rule):
@@ -166,8 +185,19 @@ class _Evaluator:
                 exposures = exposures + result.secondary_exposures
             if not result.boolean_value:
                 eval_result = False
-        return_value = rule.get("return_value", {})
+        return_value = rule.get("returnValue", {})
         rule_id = rule.get("id", "")
+
+        if eval_result:
+            config_delegate = rule.get('configDelegate', None)
+            config = self._configs.get(config_delegate)
+            if config:
+                delegated_result = self.__evaluate(user, config)
+                delegated_result.allocated_experiment = config_delegate
+                delegated_result.secondary_exposures = exposures + \
+                    delegated_result.secondary_exposures
+                return delegated_result
+
         return _ConfigEvaluation(False, eval_result, return_value, rule_id, exposures)
 
     def __evaluate_condition(self, user, condition):
