@@ -3,6 +3,7 @@ import queue
 from .statsig_event import StatsigEvent
 
 _CONFIG_EXPOSURE_EVENT = "statsig::config_exposure"
+_LAYER_EXPOSURE_EVENT = "statsig::layer_exposure"
 _GATE_EXPOSURE_EVENT = "statsig::gate_exposure"
 
 
@@ -49,6 +50,20 @@ class _StatsigLogger:
             "config": config,
             "ruleID": rule_id,
         }
+
+        if secondary_exposures is None:
+            secondary_exposures = []
+        event._secondary_exposures = secondary_exposures
+        self.log(event)
+
+    def log_layer_exposure(self, user, config, rule_id, secondary_exposures, allocated_experiment):
+        event = StatsigEvent(user, _LAYER_EXPOSURE_EVENT)
+        event.metadata = {
+            "config": config,
+            "ruleID": rule_id,
+            "allocatedExperiment": allocated_experiment or ""
+        }
+
         if secondary_exposures is None:
             secondary_exposures = []
         event._secondary_exposures = secondary_exposures
